@@ -182,6 +182,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Plone :: 5.2",
     "Framework :: Plone :: 5.3",
     "Framework :: Plone :: 6.0",
+    "Framework :: Plone :: 6.1",
     "Framework :: Plone :: Addon",
     "Framework :: Plone :: Core",
     "Framework :: Plone :: Distribution",
@@ -189,6 +190,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Pycsou",
     "Framework :: Pydantic",
     "Framework :: Pydantic :: 1",
+    "Framework :: Pydantic :: 2",
     "Framework :: Pylons",
     "Framework :: Pyramid",
     "Framework :: Pytest",
@@ -454,6 +456,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Kotlin",
     "Programming Language :: Lisp",
     "Programming Language :: Logo",
+    "Programming Language :: Lua",
     "Programming Language :: ML",
     "Programming Language :: Modula",
     "Programming Language :: OCaml",
